==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/RepositoryCore/src/com/clustercontrol/repository/bean/NodePropertyConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.bean;

/**
 * Ρѥץѥƥ饹
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class NodePropertyConstant {
    /** եƥID */
    public static final String FACILITY_ID = "facilityId";

    /** եƥ̾ */
    public static final String FACILITY_NAME = "facilityName";

    /**  */
    public static final String DESCRIPTION = "description";

    /** PINGƻ */
    public static final String PING_MONITOR = "pingMonitoring";

    /** PINGƻ륹ơ */
    public static final String PING_MONITOR_STATUS = "pingMonitoringStatus";

    /** ȴƻ */
    public static final String AGENT_MONITOR = "agentMonitoring";

    /** ȴƻ륹ơ */
    public static final String AGENT_MONITOR_STATUS = "agentMonitoringStatus";

    /** ơƻ */
    public static final String STATUS_MONITOR = "statusMonitoring";

    /** ٥ȴƻ */
    public static final String EVENT_MONITOR = "eventMonitoring";

    /**  */
    public static final String AGENT_CONTROL = "agentControl";

    /** DHCP饤 */
    public static final String DHCP_CLIENT = "dhcpClient";

    /** IPɥ쥹 */
    public static final String IP_ADDRESS_TYPE = "ipAddressType";

    /** IPɥ쥹ΥС */
    public static final String IP_ADDRESS_VERSION = "ipAddressVersion";

    /** IPv4Υɥ쥹 */
    public static final String IP_ADDRESS_V4 = "ipAddressV4";

    /** IPv6Υɥ쥹 */
    public static final String IP_ADDRESS_V6 = "ipAddressV6";

    /** ۥ̾ */
    public static final String HOST_NAME = "hostName";

    /** H/W */
    public static final String HARDWARE_TYPE = "hardwareType";

    /** ץåȥեեߥ̾ */
    public static final String PLATFORM_FAMILY_NAME = "platformFamilyName";

    /** OS̾ */
    public static final String OS_NAME = "osName";

    /** Ρ̾ */
    public static final String NODE_NAME = "nodeName";

    /** OS꡼ */
    public static final String OS_RELEASE = "osRelease";

    /** OSС */
    public static final String OS_VERSION = "osVersion";

    /** ʸå */
    public static final String CHARACTER_SET = "characterSet";

    /**  */
    public static final String ADMINISTRATOR = "administrator";

    /** Ϣ */
    public static final String CONTACT = "contact";

    /**  */
    public static final String CREATE_TIME = "createTimestamp";

    /**  */
    public static final String CREATOR_NAME = "creatorName";

    /**  */
    public static final String MODIFIER_NAME = "ModifierName";

    /**  */
    public static final String MODIFY_TIME = "ModifyTime";

    /** ǥХ̾ */
    public static final String DEVICE_NAME = "deviceName";

    /** ǥХOID */
    public static final String DEVICE_OID = "deviceOID";

    /** ǥХǥå */
    public static final String DEVICE_INDEX = "deviceIndex";

    /** ǥХ */
    public static final String DEVICE_TYPE = "deviceType";

    /** ǥХ */
    public static final String DEVICE_DESCRIPTION = "deviceDescription";

    /** ͥåȥ */
    public static final String NETWORK = "network";

    /** OS */
    public static final String OS = "os";

    /** ݼ */
    public static final String MAINTENANCE = "maintenance";

    /** ǥХ */
    public static final String DEVICE = "device";
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/RepositoryCore/src/com/clustercontrol/repository/bean/NodePropertyConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.bean;

/**
 * ノード用プロパティ定義クラス
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class NodePropertyConstant {
    /** ファシリティID */
    public static final String FACILITY_ID = "facilityId";

    /** ファシリティ名 */
    public static final String FACILITY_NAME = "facilityName";

    /** 注釈 */
    public static final String DESCRIPTION = "description";

    /** PING監視 */
    public static final String PING_MONITOR = "pingMonitoring";

    /** PING監視ステータス */
    public static final String PING_MONITOR_STATUS = "pingMonitoringStatus";

    /** エージェント監視 */
    public static final String AGENT_MONITOR = "agentMonitoring";

    /** エージェント監視ステータス */
    public static final String AGENT_MONITOR_STATUS = "agentMonitoringStatus";

    /** ステータス監視 */
    public static final String STATUS_MONITOR = "statusMonitoring";

    /** イベント監視 */
    public static final String EVENT_MONITOR = "eventMonitoring";

    /** エージェント制御 */
    public static final String AGENT_CONTROL = "agentControl";

    /** DHCPクライアント */
    public static final String DHCP_CLIENT = "dhcpClient";

    /** IPアドレス種別 */
    public static final String IP_ADDRESS_TYPE = "ipAddressType";

    /** IPアドレスのバージョン */
    public static final String IP_ADDRESS_VERSION = "ipAddressVersion";

    /** IPv4のアドレス */
    public static final String IP_ADDRESS_V4 = "ipAddressV4";

    /** IPv6のアドレス */
    public static final String IP_ADDRESS_V6 = "ipAddressV6";

    /** ホスト名 */
    public static final String HOST_NAME = "hostName";

    /** H/Wタイプ */
    public static final String HARDWARE_TYPE = "hardwareType";

    /** プラットフォームファミリ名 */
    public static final String PLATFORM_FAMILY_NAME = "platformFamilyName";

    /** OS名 */
    public static final String OS_NAME = "osName";

    /** ノード名 */
    public static final String NODE_NAME = "nodeName";

    /** OSリリース */
    public static final String OS_RELEASE = "osRelease";

    /** OSバージョン */
    public static final String OS_VERSION = "osVersion";

    /** 文字セット */
    public static final String CHARACTER_SET = "characterSet";

    /** 管理者 */
    public static final String ADMINISTRATOR = "administrator";

    /** 連絡先 */
    public static final String CONTACT = "contact";

    /** 作成日時 */
    public static final String CREATE_TIME = "createTimestamp";

    /** 作成者 */
    public static final String CREATOR_NAME = "creatorName";

    /** 更新者 */
    public static final String MODIFIER_NAME = "ModifierName";

    /** 更新日時 */
    public static final String MODIFY_TIME = "ModifyTime";

    /** デバイス名 */
    public static final String DEVICE_NAME = "deviceName";

    /** デバイスOID */
    public static final String DEVICE_OID = "deviceOID";

    /** デバイスインデックス */
    public static final String DEVICE_INDEX = "deviceIndex";

    /** デバイス種別 */
    public static final String DEVICE_TYPE = "deviceType";

    /** デバイス説明 */
    public static final String DEVICE_DESCRIPTION = "deviceDescription";

    /** ネットワーク */
    public static final String NETWORK = "network";

    /** OS */
    public static final String OS = "os";

    /** 保守 */
    public static final String MAINTENANCE = "maintenance";

    /** デバイス */
    public static final String DEVICE = "device";
}
